
using MTWorkHR.Application.Models;
using MTWorkHR.Core.Entities;
using System.Threading.Tasks;

namespace MTWorkHR.Application.Services.Interfaces
{
    public interface ILookupService 
    {
        Task<List<OrderTypeDto>> GetAllOrderType();
        Task<List<LeaveTypeDto>> GetAllLeaveType();
        Task<List<CountryDto>> GetAllCountries();
        Task<List<CityDto>> GetCityByCountry(long CountryId);

        Task<List<CountryDto>> CreateCountries();

        Task<List<IndustryDto>> GetAllIndustries();
        Task<List<JobTitleDto>> GetAllJobTitles();

        Task<List<UniversityDto>> GetAllUniversities();
        Task<List<QualificationDto>> GetAllQualifications();

        Task<List<UserTaskStatusDto>> GetAllUserTaskStatus();
    }
}
